function [] = set_forced_delay(forced_delays)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function extracts transitions and their corresponding 
% forced delays, and add them to PN strcuture. 
%
%  Reggie.Davidrajuh@uis.no (c) Version 6.0 (c) 10 july 2012  
%  Reggie.Davidrajuh@uis.no (c) Version 11.0 (c) 27 march 2024  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global PN 

Ts = PN.No_of_transitions;

%%%%%% Initialization
% initialize "Set_of_Forced_Delays(i).forced_delay" with "NaN"
% initialize "Set_of_Forced_Delays(i).wait_until" with "NaN"
for i = 1:Ts 
    PN.Set_of_Forced_Delays(i).forced_delay = NaN; 
    PN.Set_of_Forced_Delays(i).wait_until = NaN; 
end

%%%%%% extract transitions and corresponding forced delays
no_of_fd = length(forced_delays)/2; % number of forced delays 
allOthers = ''; % initially, no "allOthers" 

% extracting trans names and their forced delays
for i = 1:no_of_fd
    curr_trans_name = forced_delays{2*i -1};
    if strcmpi(curr_trans_name, 'allothers')
        allOthers = forced_delays{2*i};
        continue
    end
        
    trans_nr = check_valid_transition(curr_trans_name); 
    % get transition's forced delay of 
    forced_D = forced_delays{2*i}; 
    PN.Set_of_Forced_Delays(trans_nr).forced_delay = forced_D;    
end

% set "allothers" value to all others (with NaN value)
if not(isempty(allOthers))
    for i = 1:Ts
        if isnan(PN.Set_of_Forced_Delays(i).forced_delay)
            PN.Set_of_Forced_Delays(i).forced_delay = allOthers;
        end
    end
end

