function [Dm, D, Dp] = matrixD
% function [Dm, D, Dp]= matrixD
%
% Function name: matrixD
% Full name: Matrix D-, D, and D+
% Purpose: 
%     This function is will convert GPenSIM's Extended Incidence Matrix
%     A_e into D matrices that are used in some textbooks on Petri Nets 
%     (e.g., Moody and Antsaklis (2012). 
% Inputs}: (none)  
% Outputs: Three matrices: 1) Matrix D-, Matrix D, and 3) Matrix D+. 
% This functions uses: (none). 
% This function is used by: [in MSF and processor files] 
% Further info: See chapter 8.3, ``Avoiding PDF Files,'' 
%              in Davidrajuh (2018-Book)
% Sample use:  
% in MSF:
% pns = pnstruct('sample_pdf');
% [Dp, D, Dm] = matrixD(); 
%
%    Reggie.Davidrajuh@uis.no (c) June 2016

global PN

Ps = PN.No_of_places;
AA = PN.incidence_matrix;
Dm = AA(:, 1:Ps);
Dp = AA(:, Ps+1:end);
D = Dp - Dm;
