function [poset_Names, poset_Indices] = postset(elements)
% [postset_Names, postset_Indices] = postset(elements)
%
% Purpose: Returns the postset of set of places or
%                   transitions.
% 
% Sample Use:
%  [postset_Names, postset_Indices] = postset({'t1'});
%  [postset_Names, postset_Indices] = postset({'p1','p2','p3'});
%  [postset_Names, postset_Indices] = postset(postset(postset({'p5'})));
%
% Parameters: 
% Inputs: elements: set of element names (strings) of places or trans 
%
% Output: postset_Names: set of names (e.g., {'p5','p3','p1'});
%         postset_Indices: indices of elements in postset_Names
% 
% Functions called : get_outputplace, get_outputtrans

% Reggie.Davidrajuh@uis.no (c) 01.April.2024
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

poset_Names = {};   % to start with
poset_Indices = []; % to start with
disp('  ');

if isempty(elements)
    disp('postset of nothing is nothing ....');
    return; 
end

names = '';
for i = 1:length(elements)
    names = [names, ' "', elements{i}, '" '];
end
disp(['postset of ', names, ':']);


if is_trans(elements{1})
    %%%% checking poset of transitions
    for i = 1:length(elements)
        tIndex = is_trans(elements{i});
        outElements = get_outputplace(tIndex);
        poset_Indices = [poset_Indices outElements];
        poset_Indices = unique(poset_Indices);            
    end
    Disp_Names_of_OPlaces = '';
    Set_Names_of_OPlaces = {}; 
    if isempty(poset_Indices)
        disp(' --- none ----'); return 
    end
    for i = 1:length(poset_Indices)
        pnameI = pname(poset_Indices(i));
        Disp_Names_of_OPlaces = [Disp_Names_of_OPlaces,...
            '"', pnameI, '", '];
        Set_Names_of_OPlaces = union(Set_Names_of_OPlaces,...
            pnameI);
    end
    disp(Disp_Names_of_OPlaces(1:end-2));
    poset_Names = Set_Names_of_OPlaces;

elseif is_place(elements{1})
    %%%% checking poset of places
    for i = 1:length(elements)
        pIndex = is_place(elements{i});
        outElements = get_outputtrans(pIndex);
        poset_Indices = [poset_Indices outElements];
    end
    poset_Indices = unique(poset_Indices);
    if isempty(poset_Indices)
        disp(' --- none ----'); return 
    end    
    Disp_Names_of_OTrans = '';
    Set_Names_of_OTrans = {}; 
        for i = 1:length(poset_Indices)
            tnameI = tname(poset_Indices(i));
            Disp_Names_of_OTrans = [Disp_Names_of_OTrans,...
                '"', tnameI, '", '];
            Set_Names_of_OTrans = union(Set_Names_of_OTrans,...
                                     tnameI); 
        end
    disp(Disp_Names_of_OTrans(1:end-2));
    poset_Names = Set_Names_of_OTrans;

else
    %%%% output argument is neither place(s) nor transition(s)
    disp('Error: the output to function "poset" must be');
    disp('set of place(s) or transition(s) ...');
    return    
end