function [preset_Names, preset_Indices] = preset(elements)
% [preset_Names, preset_Indices] = preset(elements)
%
% Purpose: Returns the preset of set of places or
%                   transitions.
% 
% Sample Use:
%      [preset_Names, preset_Indices] = preset({'t1'});
%      [preset_Names, preset_Indices] = preset({'p1','p2','p3'});
%      [preset_Names, preset_Indices] = preset(preset(preset({'p5'})));
%
% Parameters: 
% Inputs: elements: set of element names (strings) of places or trans 
%
% Output: preset_Names: set of names (e.g., {'p5','p3','p1'});
%         preset_Indices: indices of elements in preset_Names
% 
% Functions called : get_inputplace, get_inputtrans

% Reggie.Davidrajuh@uis.no (c) 01.April.2024
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

preset_Names = {};   % to start with
preset_Indices = []; % to start with
disp('  ');

if isempty(elements)
    disp('preset of nothing is nothing ....');
    return; 
end

names = '';
for i = 1:length(elements)
    names = [names, ' "', elements{i}, '" '];
end
disp(['preset of ', names, ':']);

if is_trans(elements{1})
    %%%% checking poset of transitions
        for i = 1:length(elements)
            tIndex = is_trans(elements{i});
            inElements = get_inputplace(tIndex);
            preset_Indices = [preset_Indices inElements];
            preset_Indices = unique(preset_Indices);            
        end
        Disp_Names_of_IPlaces = '';
        Set_Names_of_IPlaces = {}; 
        if isempty(preset_Indices)
            disp(' --- none ----'); return 
        end
        for i = 1:length(preset_Indices)
            pnameI = pname(preset_Indices(i));
            Disp_Names_of_IPlaces = [Disp_Names_of_IPlaces,...
                '"', pnameI, '", '];
            Set_Names_of_IPlaces = union(Set_Names_of_IPlaces,...
                                     pnameI);
        end
        disp(Disp_Names_of_IPlaces(1:end-2));
        preset_Names = Set_Names_of_IPlaces;

elseif is_place(elements{1})
    %%%% checking preset of places
    for i = 1:length(elements)
        pIndex = is_place(elements{i});
        inElements = get_inputtrans(pIndex);
        preset_Indices = [preset_Indices inElements];
    end
    preset_Indices = unique(preset_Indices);
    if isempty(preset_Indices)
        disp(' --- none ----'); return 
    end
    Disp_Names_of_ITrans = '';
    Set_Names_of_ITrans = {}; 
        for i = 1:length(preset_Indices)
            tnameI = tname(preset_Indices(i));
            Disp_Names_of_ITrans = [Disp_Names_of_ITrans,...
                '"', tnameI, '", '];
            Set_Names_of_ITrans = union(Set_Names_of_ITrans,...
                                     tnameI); 
        end
    disp(Disp_Names_of_ITrans(1:end-2));
    preset_Names = Set_Names_of_ITrans;

else
    %%%% input argument is neither place(s) nor transition(s)
    disp('Error: the input to function "preset" must be');
    disp('set of place(s) or transition(s) ...');
    return    
end

