function [iniMarking] = initial_marking()
% function [iniMarking] = initial_marking()
%           initial marking (Initial state)
%
% Purpose: After the simulation start (gpensim is running), 
% we may want to know the initial state in the processors. 
% This function prints the initial marking on screen in a 
% compact form (e.g., `3p2 + 5p3') also returns it as 
% a vector (length is number of places).
%
%   Input Parameter: (none)  
%   Output Parameter: A vector of natural numbers 
%       (length is $n_p$, number of places); 
%       in this vector, each column represents number of 
%       tokens in a place identified by the column as index. 
%       E.g., in a Petri net with 5 places, p1 to p5, and 
%       if the initial marking is (3p2 + 5p3), then the vector 
%       returned will be [0 3 5 0 0].
%
%   This function uses}: (none) \\
%   Sample use:  See the example (Example-11) given 
%   in the ** Reference Manual **
%
%   Reggie.Davidrajuh@uis.no    (c)  03 March 2024

global PN 

iniMarking = PN.initial_marking;

markings_str = markings_string (iniMarking);
disp(['Initial marking: ', markings_str]);
