function [COTREE_TC] = cotreeTC(pni, max_states)   
%        [COTREE_TC] = cotreeTC(pni, max_states)   
% Name:	coverability (reachability) tree with with Time and Cost
% Purpose:	Creates the reachability tree of finite number of states
%           the tree includes timing and costs
% Input parameters:	Petri net sturcture with ini dynamics 
%                                   (output by ‘inidynamics’)
%                   maximum-no-of-states  
% Outputs: Output on screen: a printout of state space 
%    (similar to the rpintout of cotree); 
%    however, the time and cost of the states are also shown.
% Outputs: output parameter: A matrix in which each row 
%         corresponds to a state. In a row, the first part 
%         is the marking, followed by: fired transition, 
%         parent state, time of the state, and cost of the state.    
% Uses:	print_retree
%       
% Used by:	[main simulation file]
%
% Out parameters:	[RETREE]
%
% Example:	
%   % in main simulation file
%   png = pnstruct('cotree_example_def');
%   dyn.m0 = {'p1',2, 'p4', 1};
%   dyn.ft = {'t1',2, 't2', 1};
%   dyn.fc = {'t1',16, 't2', 32};
%   pni = initialdynamics(png, dyn);
%   RTTREE = retree(pni);
%

%   Reggie.Davidrajuh@uis.no (c) Version 8.0 (c) May 2013
%   Reggie.Davidrajuh@uis.no (c) Version 10.0 (c) Feb 2023  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if eq(nargin, 1)
    max_states = 50; % default max states
end

[COTREE_TC] = retree(pni, max_states);


