function [L, B] = extractLB(constraints)
%        [L, B] = extractLB(constraints)
% Extract L and B from the constraints
% Purpose: To extract L matrix (left part of the inequality)  
%      and B vector (limiting value (right part of the inequality) 
%      from the constraints given in GPenSIM formulation. 
%
% Input Parameter:  Constraints in GPenSIM formulation. 
% Output Parameter: 1) L matrix (dimension: number of constraints X 
%     number of process places) and 
%                  2) B vector (dimension: number of constraints).
% This function uses}: (none). 
% This function is used by: functions 'supervisorSim' and 'supervisorSyn' 
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%  Sample Constraint formulation %%%%%%%%%%%%%%%
% Room1.L = {'Room1C',1, 'Room1M',1}; Room1.B = 1; 
% Room2.L = {'Room2C',1, 'Room2M',1}; Room2.B = 1; 
% Room3.L = {'Room3C',1, 'Room3M',1}; Room3.B = 1; 
% constraints = [Room1, Room2, Room3, Room4, Room5];
%
%  Reggie.Davidrajuh@uis.no   (c)  08.March.2024

global PN
Ps = PN.No_of_places;

lenConstr = length(constraints);

L = zeros(lenConstr, Ps);   
B = zeros(lenConstr, 1);

for i = 1:lenConstr
    b = constraints(i).B; %.B = .b §§§§§§§§§§
    B(i, 1) = b;
    l = constraints(i).L; %.L = .l §§§§§§§§§§  
    for j = 1:length(l)/2
        p_name = l{2*j - 1}; 
        p_index = check_valid_place(p_name);
        L(i, p_index) = l{2*j};
    end
end
