function [] = prncontroller(Sys)
%        [] = prncontroller(Sys)
%  Print Controller Info
%
% Purpose: Prints the details of the controller on screen 
%      in an intelligible manner, with control (slack) 
%      places and arcs.
%
% Input Parameter: 
%     1) Simulation results on controlled system - output of 'gpensim'
%
%  Output Parameter: none. 
%  Output on screen: prints only the composition of the controller 
%     with control (slack) places and initial tokens on control places.
%
% This function uses: none.
% This function is used by: [main simulation file.] and prnsys()
%
%  Reggie.Davidrajuh@uis.no (c) Version 11.0 (c) 10 Sep 2024  

global PN
PN = Sys;
Ps = PN.No_of_places;
Cs = PN.No_of_control_places;
Ts = PN.No_of_transitions;
A = PN.incidence_matrix;

disp(' ');
disp('======= Controller Composition ======= ');

disp(' '); 
for i = 1:Cs
    pcx = Ps-Cs+i;
    place_name = pname(pcx);
    disp(['Control place: ', place_name]);
    % print the input arcs from the control places to transitions 
    ain = A(:, pcx);
    str = '    ';
    for j = 1: Ts
        if ain(j)
            trans_name = tname(j);
            str = [str, '(', place_name, ' -> ', trans_name, ' : ',...
                int2str(ain(j)), ')   '];
        end
    end
    disp(str);
    
    % print the output arcs, from transitions to the control places
    aout = A(:, Ps+pcx:end);
    str = '    ';
    for j = 1: Ts
        if aout(j)
            trans_name = tname(j);
            str = [str, '', trans_name, ' -> ', place_name, ' : ',...
                int2str(aout(j)), ')   '];
        end
    end
    disp(str);     
end

muC0 = PN.muC0;
% print initial markings (tokens) on the control places 
if any(PN.No_of_control_places) 
    disp(' '); disp('Initial markings on the Control places : '); 
    for i = 1:Cs
        if muC0(i)
            place_name = pname(Ps-Cs+i);
            disp([place_name, ': ', int2str(muC0(i))]); 
        end 
    end     
end
disp(' ');
