function [] = prnsys(sim, ini_dynamics)
% function [] = prnsys (sim, ini_dynamics)
%    Print system info 
%
% Purpose: Prints the details of the controlled system 
%    (the plant (process) and the controller) on screen in 
%    an intelligible manner, with places, transitions, and arcs.
%
%  Sample use: prnsys(sim, dyn)
%  Input arguments: 
%     1) sim: simulation results output by function 'gpensim'
%     2) ini_dynamics: the input to function 'initialdynamics'
%
%  Output arguments: none 
%  Output on screen: prints two sections on screen:
%     1) the composition of the plant (process) 
%        with places transitions, arcs, and initial tokens.
%     2) the composition of the controller with control (slack) 
%        places and initial tokens on the control places.
%  Uses: 
%       prnsys_connection(), 
%       prncontroller(sim),  % to print composition of controller part.
%       get_initial_marking(), marking_string()
%
%  Reggie.Davidrajuh@uis.no (c) Version 6.0 (c) 10 july 2012  


global PN
PN = sim;

Ps = PN.No_of_places;
Ts = PN.No_of_transitions;

if isfield(PN, 'No_of_control_places')
    Cs = PN.No_of_control_places;
else Cs = 0;
end

disp(' ');
disp('======= Plant (Process) Composition ======= ');
disp(['There are ', int2str(Ps-Cs), ' process places']);
disp(['There are ', int2str(Ts), ' process transitions']);
if Cs, disp(['There are ', int2str(Cs), ' control places']); end

disp(['Process Petri Net: ', PN.name]);
prnsys_connection;

X = zeros(1, Ps); % initial assumption
if eq(nargin, 2)
    X = get_initial_marking(ini_dynamics); % intial marking
    disp(' '); disp('Initial markings on the Process places: ');
    str = markings_string (X, [1 Ps-Cs]); 
    disp(str); disp(' ');
end

% Add the number of arcs (connections)to PN
indices = find(PN.incidence_matrix ~= 0);
No_of_arcs = numel(indices);
disp(['There are ', int2str(No_of_arcs ), ' arcs in total']);
disp(' ');

if Cs
    prncontroller(sim);
end
