function [PN] = supervisorSim(pni, constraints)
% function [PN] = supervisorSim(pni, constraints)
%     supervisor Simple
%   
%   Purpose: Synthesis of a supervisor when 
%            all transitions are assumed 
%            controllables & observables
%
%  Input arguments: 
%       1) Plant: pni - Petri net with initial dynamic
%          (output of in initialdynamics)
%       2) Constraints: set of linear inequalities
%
%  Output argument: 
%       Controlled System as PN 
%  (use 'printsys' to printout the controlled sys)
%  (use 'gpensim' to run simuations on the controlled sys)
%       
%  Functions used:  extractLB, gpensim_2_PNCT,  
%                   imControlledSys, addSlacks2GP
%
%
%  Reggie.Davidrajuh@uis.no   (c)  08.March.2024


global PN
PN = pni;

% extract L and B from constraints, and Dp
[L, B] = extractLB(constraints);  

% incidence matrix of plant
[~,~,Dp] = gpensim_2_PNCT(PN.incidence_matrix);

mu0 = transpose(PN.X);

%%%%%%%%%%%%  controller (synthesis of supervisor)  
Dc = -1 * L * Dp;  
muC0 = B  - L * mu0;

%%%%%%%%%%%%% Update Controlled Sys %%%%%%%%%%%%%
% update incidence matrix for controlled system
imControlledSys(Dc, size(L,1));

% add slack variables to the list of global_places 
addSlacks2GP(muC0);
