function [all_ok, TokenSUM] = verifyCOTREE(COTREE, constraints)
% function [all_ok, TokenSUM] = verifyCOTREE(COTREE, constraints)
%     Verify supervisor's action with COTREE
%   
%   Purpose: To verify whether the controlled systems
%            behaves as demanded by the constraints
%
%  NOTE: *** this function will NOT work for reachability tree with 
%             infinite (omega) tokens ***
%            (unbounded net)
%
%  Input arguments: 
%       1) COTREE: reachability tree (output of 'cotree' 
%                    on controlled system  
%       2) Constraints: linear inequalities in GPenSIM formulation.
%
%  Output argument: 
%       1) all_Ok : (Boolean value) verification is successful?
%       2) TokenSUM: sum of tokens in places satisfying constraints
% 
%  Functions used:  (none)
%       
%  Reggie.Davidrajuh@uis.no   (c)  08.March.2024


disp(' ');
disp('***************************************************');
disp('Now verifying the proposed controller action !!!!');
disp('           based on COTREE !!!!');
disp('***************************************************');
disp('');

if any(find(COTREE==inf))
    disp('some places get infinite tokens');
    disp('hence, verification based on COTREE ');
    disp('is not possible!!!');
    disp('- try the function "controllerPerform" instead ...')
    all_ok = false; 
    TokenSUM = [];
    return
end

%Ps = simResults.No_of_places;
Ps = size(COTREE, 2) - 3; % number of columns - 3

% extract L and B
[L, B] = extractLB(constraints);

% number of constraints
lenConstr = length(constraints);

% number of states in COTREE
rows_of_CT = size(COTREE, 1);

all_ok = true; % optimistic assumption, to begin with

TokenSUM = zeros(rows_of_CT, lenConstr);

% the main loop
for ci = 1:lenConstr  % for each constraint
    Li = L(ci, :);
    bi = B(ci, :);

    % check each state in COTREE
    for rowj = 1:rows_of_CT
        tokens = COTREE(rowj, 1:Ps); 
        toksum = tokens * Li';       
        TokenSUM(rowj, ci) = toksum;
        if gt(toksum, bi)
            disp(['invalid control action in row-',...
                     int2str(rowj)]);
            disp('verification went wrong here ...');
            all_ok = false; 
            load gong.mat; sound(y);
            return
        end
    end
end
disp('All the constraints are verified !!!!');
