function [] = writePostProcessors(controlledSys)
% function [] = writePostProcessors(controlledSys)
%     write Post-Processor Files
%   
%  Purpose: to write (create) post-processor files based on 
%            the synthesis of a supervisor 
%
%  Input arguments: 
%       1) controlledSys
%
%  Output argument: 
%       
%  Functions used:  (none)
%
%  Reggie.Davidrajuh@uis.no   (c)  28.Sep.2024

if or(not(isfield(controlledSys, 'No_of_control_places')), ...
        not(controlledSys.No_of_places))
    disp('This functions works only on controlled systems');
    disp('There are no visible slack variables')
end

Ts = controlledSys.No_of_transitions; % number of transitions 
Ps = controlledSys.No_of_places;  % number of overall places
Nslacks = controlledSys.No_of_control_places; % number of slacks


for ti = 1:Ts 
    control_outputs = ...
        controlledSys.incidence_matrix(ti,2*Ps-Nslacks+1:end);
    if any(control_outputs)
        filename = [tname(ti), '_post.m'];
        fid = fopen(filename, 'w');  % open the file with write permission
        lineStr = ['function [] = ', ...
            filename(1:end-2), '(transition)'];
        fprintf(fid,'%s\n',lineStr);
        lineStr = ['% Post-processor for transition "', tname(ti), '"'];  
        fprintf(fid,'%s\n',lineStr);
        lineStr = '%  '; fprintf(fid,'%s\n',lineStr);
        lineStr = ['% this file ("', filename,... 
                    '") is automatically generated ']; 
        fprintf(fid, '%s\n', lineStr);
        lineStr = '%   by the function "writePostProcessors"'; 
        fprintf(fid, '%s\n\n', lineStr);
        lineStr = 'global global_info  % slacks are attached to global_info';
        fprintf(fid, '%s\n\n', lineStr);
        
        fprintf(fid, '%s\n', '% after firing of the transition ');
        fprintf(fid, '%s\n', '% increase the slack variables');
        fprintf(fid, '%s\n', '%    (add "tokens" to the slack "places")'); 
        % Loop 2: writing slack deductions
        for cpi = 1:Nslacks
            control_input_arcweight = control_outputs(cpi);
            if control_input_arcweight
                lineStr = ['global_info.slack', int2str(cpi), ...
                    ' = ', 'global_info.slack', int2str(cpi), ... 
                    ' + ', int2str(control_input_arcweight), ';'];
                fprintf(fid, '%s\n', lineStr);
            end                
        end % cpi = 1:Nslacks
        fprintf(fid, '\n');
        fclose(fid);
    end
end
