function [] = writePreProcessors(controlledSys)
% function [] = writePreProcessors(controlledSys)
%     write Pre-Processor Files
%   
%  Purpose: to write (create) pre-processor files based on 
%            the synthesis of a supervisor 
%
%  Input arguments: 
%       1) controlledSys
%
%  Output argument: 
%       
%  Functions used:  (none)
%
%  Reggie.Davidrajuh@uis.no   (c)  28.Sep.2024


if or(not(isfield(controlledSys, 'No_of_control_places')), ...
        not(controlledSys.No_of_places))
    disp('This functions works only on controlled systems');
    disp('There are no visible slack variables')
end

Ts = controlledSys.No_of_transitions; % number of transitions 
Ps = controlledSys.No_of_places;  % number of overall places
Nslacks = controlledSys.No_of_control_places; % number of slacks


for ti = 1:Ts 
    control_inputs = ...
        controlledSys.incidence_matrix(ti,Ps-Nslacks+1:Ps);
    if any(control_inputs)
        filename = [tname(ti), '_pre.m'];
        fid = fopen(filename, 'w');  % open the file with write permission
        lineStr = ['function [fire, transition] = ', ...
            filename(1:end-2), '(transition)'];
        fprintf(fid,'%s\n',lineStr);
        lineStr = ['% Pre-processor for transition "', tname(ti), '"'];  
        fprintf(fid,'%s\n',lineStr);
        lineStr = '% '; fprintf(fid,'%s\n',lineStr);
        lineStr = ['% this file ("', filename,...
            '") is automatically generated ']; 
        fprintf(fid, '%s\n', lineStr);
        lineStr = '%    by the function "writePreProcessors" ';
        fprintf(fid, '%s\n\n', lineStr);
        lineStr = 'global global_info  % slacks are attached to global_info';
        fprintf(fid, '%s\n\n', lineStr);
        
        lineStr = 'fire = 1; % initial assumption';
        fprintf(fid, '%s\n', lineStr);
        
        % Loop 1: writing firing conditions
        for cpi = 1:Nslacks
            control_input_arcweight = control_inputs(cpi);
                if gt(control_input_arcweight,1)
                    lineStr = ['fire = and(fire, ge(global_info.slack',...
                        int2str(cpi), ...
                        ',' int2str(control_input_arcweight), ')); '];
                    fprintf(fid, '%s\n', lineStr);
                elseif eq(control_input_arcweight,1)
                    lineStr = ['fire = and(fire, global_info.slack',...
                        int2str(cpi), ');'];
                    fprintf(fid, '%s\n', lineStr);
                end
        end % cpi = 1:Nslacks

        fprintf(fid, '\n\n');
        fprintf(fid, '%s\n', '% if the transition is allowed to fire');
        fprintf(fid, '%s\n', '% then reduce the slack variables');
        fprintf(fid, '%s\n', '%    (remove "tokens" from the slack "places")'); 
        fprintf(fid, '%s\n', 'if fire');    
        % Loop 2: writing slack deductions
        for cpi = 1:Nslacks
            control_input_arcweight = control_inputs(cpi);
            if control_input_arcweight
                lineStr = ['     global_info.slack', int2str(cpi), ...
                    ' = ', 'global_info.slack', int2str(cpi), ... 
                    ' - ', int2str(control_input_arcweight), ';'];
                fprintf(fid, '%s\n', lineStr);
            end                
        end % cpi = 1:Nslacks
        fprintf(fid, '%s\n', 'end');
        fprintf(fid, '\n');
        fclose(fid);
    end
end
