function [V] = dfs_visit (V, u, No_of_trees)
% function [V] = dfs_visit (V, u, No_of_trees)
% function depth-first-search visit
% ** V is the set of nodes
%       V.A is the incidence matrix
%       V.nodes is the set of nodes
%       V.time = is the current time (current step)
% ** u is the current node
%
%      Reggie Davidrajuh (c) August 2011

global global_info
DBM = false;
if isfield(global_info, 'debug_mode')
    DBM = global_info.debug_mode; 
end

number_of_nodes = length(V.nodes);

V.time = V.time + 1;
V.nodes(u).d = V.time;
V.nodes(u).color = 'gray';
V.nodes(u).tree_no = No_of_trees;

if DBM 
    disp([V.nodes(u).name, '(', int2str(V.nodes(u).d), '/ )']); 
end

for v = 1:number_of_nodes % scan all the nodes connected with u
    if V.A(u, v)   % if there is a connection between (i, j)
        if strcmp(V.nodes(v).color, 'white')
            if DBM
                disp(['Tree edge: ',V.nodes(u).name,' to ',V.nodes(v).name]);
            end
            V.nodes(v).pi = u; 
            V = dfs_visit (V, v, No_of_trees);
        elseif strcmp(V.nodes(v).color, 'gray')
            if DBM
                disp(['Back edge: ',V.nodes(u).name,' to ',V.nodes(v).name]);
            end
        else
            if DBM
                disp(['Cross/Forward edge: ', ...
                    V.nodes(u).name,' to ',V.nodes(v).name]);                
            end
        end
    end % if V.A
end % for j = 1:

V.nodes(u).color = 'black';
V.time = V.time + 1;
V.nodes(u).f = V.time;
if DBM 
    disp(['Black node: ', V.nodes(u).name, ...
        '(', int2str(V.nodes(u).d), '/', int2str(V.nodes(u).f), ')']);
end
