function [endPlacesTrans] = ends()
% function [endPlacesTrans] = ends()
%       Ends (Places and Transitions) of a Causal Net
%
% Purpose:
% This function finds the ends of a Causal Net. 
% 
% Input arguments:
%
% Output arguments:  is a set of three vectors:
%   vector-1 (one element): the length of end places
%   vector-2: [set of end place indices]
%   vector-3: [set of end trans indices] 
% 
% Used by: ()
%
%       Reggie.Davidrajuh@uis.no (c) January 2023
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global PN

Ps = PN.No_of_places;  
Ts = PN.No_of_transitions;
A = PN.incidence_matrix;

% incidence matrices
Ainn = A(:, 1:Ps);
Aout = A(:, Ps+1:2*Ps);


%%%%%%%%%%%%%% End places %%%%%%%%%%%%%% 
columsum_Ainn = sum(Ainn);
endPlaces = find(columsum_Ainn == 0);
if not(isempty(endPlaces))
    disp('*** These are the ends :');
    Place_Names = '';
    for i = 1: numel(endPlaces)
        Place_Names = [Place_Names, '  ', ...
                        PN.global_places(endPlaces(i)).name]; 
    end
    disp(Place_Names);
else
    disp('*** There are NO ends in this causal net!');
end


%%%%%%%%%%%%%% End transitions %%%%%%%%%%%%%% 
rowsum_Aout = sum(Aout,2);
endTrans = find(rowsum_Aout == 0);
if not(isempty(endTrans))
    disp('*** These are the end transitions :');
    Trans_Names = '';
    for i = 1: numel(endTrans)
        Trans_Names = [Trans_Names, '  ', ...
                        PN.global_transitions(endTrans(i)).name]; 
    end
    disp(Trans_Names);
else
    disp('*** There are NO end transitions in this causal net!');
end

endPlacesTrans = [numel(endPlaces), endPlaces, endTrans];
