function [PNEG] = is_markedGraph()
% function [classtype] = is_markedGraph()
%       Is Marked Graph
%
% Purpose:
% This function checks whether the Petri net is a Marked Graph. 
% 
% Uses:
%   pnt = is_markedGraph()   
% 
%
% Used by: ()
%
%       Reggie.Davidrajuh@uis.no (c) February 2022
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global PN

Ps = PN.No_of_places;  Ts = PN.No_of_transitions;
A = PN.incidence_matrix;

% Flag-3: Event (Marked) Graph (every place has exactly 
%          one input and one output transition
Ainn = A(:, 1:Ps);  Aout = A(:, Ps+1:2*Ps);
AinnT = Ainn';  AoutT = Aout';
PNEG = 1; % initial assumption
i = 1;
while and(le(i, Ps), PNEG) % check every place, one by one 
    rowinn = AinnT(i,:);    rowout = AoutT(i,:);
    no_of_input_Ts = length(find(rowinn));
    no_of_output_Ts = length(find(rowout));
    PNEG = and(eq(no_of_input_Ts, 1), eq(no_of_output_Ts, 1));
    i = i + 1;
end
