function [PNSM] = is_stateMachine()
% function [classtype] = is_stateMachine()
%       Is State Machine
%
% Purpose:
% This function checks whether the Petri net is a state Machine. 
% 
% Uses:
%   pnt = is_stateMachine()   
% 
%
% Used by: ()
%
%       Reggie.Davidrajuh@uis.no (c) February 2022
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global PN

Ps = PN.No_of_places;  Ts = PN.No_of_transitions;
A = PN.incidence_matrix;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Flag-2: PN State Machine
% In a PN State Machine, every transition has exactly 
%     one input and one output place
Ainn = A(:, 1:Ps);  Aout = A(:, Ps+1:2*Ps);
PNSM = 1; % initial assumption
i = 1;
while and(le(i, Ts), PNSM) % check every transition, one by one 
    rowinn = Ainn(i,:);    rowout = Aout(i,:);
    no_of_input_places = length(find(rowinn));
    no_of_output_places = length(find(rowout));
    PNSM = and(eq(no_of_input_places, 1), eq(no_of_output_places, 1));
    i = i + 1;
end
