function [Places] = outsets()
% function [Places] = outsets()
%       Outsets of a Causal Net
%
% Purpose:
% This function finds the outsets of a Causal Net. 
% 
% Input arguments:
%
% Output arguments:  [set of place indices] 
% 
%
% Used by: ()
%
%       Reggie.Davidrajuh@uis.no (c) January 2023
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global PN

Ps = PN.No_of_places;  
Ts = PN.No_of_transitions;
A = PN.incidence_matrix;

% incidence matrices
Ainn = A(:, 1:Ps);
Aout = A(:, Ps+1:2*Ps);


%%%%%%%%%%%%%% Outset places %%%%%%%%%%%%%% 
columsum_Aout = sum(Aout);
Places = find(columsum_Aout == 0);
if not(isempty(Places))
    disp('*** The following places are outsets:');
    Place_Names = '';
    for i = 1: numel(Places)
        Place_Names = [Place_Names, '  ', ...
                        PN.global_places(Places(i)).name]; 
    end
    disp(Place_Names);
else
    disp('*** There are no outsets in this causal net !!');
end

